@@ -24,7 +24,7 @@ def decode(data, b64decode=True):
     return json.loads(decoded.decode("utf-8"))
 
 
-def _encode(data, b64decode=False):
+def _encode(data, b64encode=False):
     encoded = json.dumps(data).encode("ascii")
     if b64encode:
         encoded = base64.b64encode(encoded)
